==> xtpcpp_0.4.16.orig.tar.gz: xtpcpp-0.4.16/src/gui/xic_view/xic_widgets/zivydialog.h <==
/**
 * \file src/gui/xic_view/xic_widgets/zivydialog.h
 * \date 30/5/2018
 * \author Olivier Langella
 * \brief dialog window to edit Zivy quantification method
 */
/*******************************************************************************
 * Copyright (c) 2018 Olivier Langella <olivier.langella@u-psud.fr>.
 *
 * This file is part of XTPcpp.
 *
 *     XTPcpp is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     XTPcpp is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contributors:
 *     Olivier Langella <olivier.langella@u-psud.fr> - initial API and
 *implementation
 ******************************************************************************/

#ifndef ZIVYDIALOG_H
#define ZIVYDIALOG_H

#include <QDialogButtonBox>
#include <QDialog>
#include "zivywidget.h"

class ZivyDialog : public QDialog
{
  Q_OBJECT

  public:
  explicit ZivyDialog(QWidget *parent = 0);
  virtual ~ZivyDialog();


  void setZivyParams(const ZivyParams &params);
  const ZivyParams getZivyParams() const;

  private:
  ZivyWidget *_p_zivy_widget;
  QDialogButtonBox *_p_button_box;
};

#endif // ZIVYDIALOG_H

==> xtpcpp_0.4.18.orig.tar.gz: xtpcpp-0.4.18/src/gui/xic_view/xic_widgets/zivydialog.h <==
/**
 * \file src/gui/xic_view/xic_widgets/zivydialog.h
 * \date 30/5/2018
 * \author Olivier Langella
 * \brief dialog window to edit Zivy quantification method
 */
/*******************************************************************************
 * Copyright (c) 2018 Olivier Langella <olivier.langella@u-psud.fr>.
 *
 * This file is part of XTPcpp.
 *
 *     XTPcpp is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     XTPcpp is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contributors:
 *     Olivier Langella <olivier.langella@u-psud.fr> - initial API and
 *implementation
 ******************************************************************************/

#ifndef ZIVYDIALOG_H
#define ZIVYDIALOG_H

#include <QDialogButtonBox>
#include <QDialog>
#include "zivywidget.h"
#include "xicexportparam.h"

class ZivyDialog : public QDialog
{
  Q_OBJECT

  public:
  explicit ZivyDialog(QWidget *parent = 0);
  virtual ~ZivyDialog();


  void setZivyParams(const ZivyParams &params);
  const ZivyParams getZivyParams() const;

  void setXicExportParams();
  void saveXicExportSettings();

  private:
  ZivyWidget *_p_zivy_widget;
  XicExportWidget *mp_xicExportWidget;
  QDialogButtonBox *_p_button_box;
};

#endif // ZIVYDIALOG_H
